@@ -3,7 +3,7 @@ percentThresholds = (90, 75)
 flushInterval = 10.0 # Seconds to flush stats
 timerPrefix = 'stats.timers'
 counterPrefix = 'stats'
-guagePrefix = 'stats'
+gaugePrefix = 'stats'
 deleteCounters = False
 
 graphitePort = 2003
